==> treeland-debug-0.5.18-1.1-x86_64_v4.pkg.tar.zst: usr/src/debug/treeland/treeland/src/.qt/rcc/qrc_qmake_Treeland.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.8.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0xcb,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xb,0x5,0xd,0xe,0x0,0xe6,0x53,0x3b,0x1e,0x50,0x8f,0x3a,
  0xbc,0xb1,0x95,0xc8,0xb8,0x65,0x73,0xbb,0x18,0x61,0x6a,0x97,0xfb,0xf8,0x39,0x7c,
  0x1f,0x3e,0x26,0x63,0xae,0x6a,0xb2,0x99,0xc5,0xaa,0x21,0x32,0x0,0x33,0x0,0x33,
  0x0,0x96,0x67,0xe0,0xf0,0xa5,0x33,0x6c,0x2e,0x67,0x59,0x0,0x2b,0x3d,0x3d,0xcc,
  0x1a,0x62,0xe5,0xbb,0xae,0x74,0xcd,0x71,0xf9,0x56,0x1b,0x6e,0xf3,0x74,0x8a,0xe,
  0x76,0x45,0x9d,0xd3,0x9f,0x38,0xbb,0x7a,0xea,0x9a,0xe8,0xa5,0xfb,0x39,0xe2,0xdc,
  0xc5,0x68,0xad,0xd0,0x14,0x51,0xfa,0xbd,0xdf,0x1a,0xde,0x52,0xe2,0x8,0x55,0x57,
  0xc6,0xf7,0x6,0xb6,0xd1,0xd3,0xc9,0x5b,0xed,0xe4,0x6d,0x3f,0x70,0x16,0xee,0x5a,
  0x23,0x70,0xd,0xcd,0x79,0x9b,0x13,0x0,0x8,0x9c,0x8e,0xb0,0xe3,0x23,0xe3,0xb4,
  0x94,0x21,0xcd,0xf3,0x3c,0x1d,0xee,0x14,0xc4,0xcf,0xa2,0x84,0x54,0x7b,0x31,0x19,
  0x70,0xbb,0xba,0x7e,0xc0,0x96,0x7a,0x46,0x2d,0x7d,0xda,0xc0,0xee,0x78,0x2e,0x4b,
  0x1f,0x21,0xe3,0xbe,0xb5,0x57,0x64,0x98,0x65,0x8,0xd5,0x5a,0x31,0xe8,0x2d,0xe1,
  0x55,0xf1,0x3e,0xe2,0x2d,0x60,0x1b,0x25,0x15,0xcd,0xab,0xa6,0xbc,0xdd,0xee,0xe,
  0x9d,0x63,0xc3,0xe4,0xd5,0x4b,0x52,0x2f,0x3c,0xca,0x44,0xd5,0xb6,0xa9,0x49,0x1d,
  0x35,0xe9,0xe2,0x9d,0xd3,0xdd,0xf,0xd8,0x55,0x82,0x5d,0x2f,0x67,0xc8,0x2f,0x6b,
  0x78,0xae,0x6e,0x97,0x24,0x4,0x47,0xe7,0x2,0x64,0xa8,0x71,0x8a,0x10,0x49,0x20,
  0x35,0xb,0xb,0xc,0xd3,0x1,0x20,0x44,0xe8,0x38,0xdb,0x1c,0x21,0x10,0x8a,0x12,
  0x62,0x90,0x31,0x44,0x13,0x29,0x21,0x49,0xea,0x53,0x1c,0x58,0x42,0xce,0x36,0xa2,
  0x49,0x96,0xc7,0x8b,0xb6,0x7d,0xc3,0xdd,0x86,0x26,0xb8,0xb7,0x34,0x9d,0x2d,0xd8,
  0x95,0x27,0x6b,0x23,0x43,0x63,0x84,0xda,0x80,0xa2,0xd1,0xf,0x54,0x99,0x5f,0xc,
  0xf3,0x2,0x6b,0xd3,0xb0,0x50,0x85,0xb3,0x76,0xf1,0xf8,0x90,0x3e,0x41,0x3b,0x3a,
  0x12,0x5e,0xb2,0xea,0x68,0x4,0x7c,0xae,0x6,0xfe,0xdc,0xd3,0x48,0xa,0xd7,0xf1,
  0xdd,0x81,0x4b,0xbe,0x90,0xa2,0x8c,0xb9,0x5e,0xdf,0x9e,0xf9,0x57,0x19,0x20,0x57,
  0x1e,0x3f,0xe4,0xa5,0xd5,0xd4,0x9a,0xa0,0x8f,0xca,0x7f,0xf2,0xd6,0xc0,0x88,0xa8,
  0xa9,0x5a,0xf4,0xda,0x5a,0x8f,0xed,0x34,0x34,0xf5,0x4e,0x98,0x98,0xc7,0x98,0xbb,
  0xb,0x2a,0xa3,0xa7,0x5a,0x97,0xd1,0x4f,0xad,0x4c,0x62,0xc,0xae,0xf9,0x4c,0xc7,
  0x7,0xba,0x56,0x7d,0x77,0x52,0xdd,0x8c,0x42,0xea,0x51,0x99,0x32,0x96,0x50,0xad,
  0xe3,0x61,0xe5,0x7,0x80,0x2c,0xa8,0x40,0x3a,0x81,0x1,0x2d,0x9b,0xb7,0xd8,0x39,
  0x95,0x4a,0xaa,0x28,0xcb,0x68,0xfc,0xab,0xcc,0xab,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // Treeland
  0x0,0x8,
  0x8,0xbc,0x2f,0x24,
  0x0,0x54,
  0x0,0x72,0x0,0x65,0x0,0x65,0x0,0x6c,0x0,0x61,0x0,0x6e,0x0,0x64,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x95,0x3c,0x82,0xc5,0x30,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x95,0x3c,0x82,0xc5,0x30,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x95,0x3c,0x82,0xc5,0x30,
  // :/qt/qml/Treeland
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x95,0x3c,0x82,0xc5,0x30,
  // :/qt/qml/Treeland/qmldir
  0x0,0x0,0x0,0x2c,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x95,0x3c,0x82,0xc5,0x30,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Treeland)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Treeland)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Treeland)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Treeland)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Treeland)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Treeland)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> treeland-debug-0.5.20-1.1-x86_64_v4.pkg.tar.zst: usr/src/debug/treeland/treeland/src/.qt/rcc/qrc_qmake_Treeland.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.8.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0xcb,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xb,0x5,0xd,0xe,0x0,0xe6,0x53,0x3b,0x1e,0x50,0x8f,0x3a,
  0xbc,0xb1,0x95,0xc8,0xb8,0x65,0x73,0xbb,0x18,0x61,0x6a,0x97,0xfb,0xf8,0x39,0x7c,
  0x1f,0x3e,0x26,0x63,0xae,0x6a,0xb2,0x99,0xc5,0xaa,0x21,0x32,0x0,0x33,0x0,0x33,
  0x0,0x96,0x67,0xe0,0xf0,0xa5,0x33,0x6c,0x2e,0x67,0x59,0x0,0x2b,0x3d,0x3d,0xcc,
  0x1a,0x62,0xe5,0xbb,0xae,0x74,0xcd,0x71,0xf9,0x56,0x1b,0x6e,0xf3,0x74,0x8a,0xe,
  0x76,0x45,0x9d,0xd3,0x9f,0x38,0xbb,0x7a,0xea,0x9a,0xe8,0xa5,0xfb,0x39,0xe2,0xdc,
  0xc5,0x68,0xad,0xd0,0x14,0x51,0xfa,0xbd,0xdf,0x1a,0xde,0x52,0xe2,0x8,0x55,0x57,
  0xc6,0xf7,0x6,0xb6,0xd1,0xd3,0xc9,0x5b,0xed,0xe4,0x6d,0x3f,0x70,0x16,0xee,0x5a,
  0x23,0x70,0xd,0xcd,0x79,0x9b,0x13,0x0,0x8,0x9c,0x8e,0xb0,0xe3,0x23,0xe3,0xb4,
  0x94,0x21,0xcd,0xf3,0x3c,0x1d,0xee,0x14,0xc4,0xcf,0xa2,0x84,0x54,0x7b,0x31,0x19,
  0x70,0xbb,0xba,0x7e,0xc0,0x96,0x7a,0x46,0x2d,0x7d,0xda,0xc0,0xee,0x78,0x2e,0x4b,
  0x1f,0x21,0xe3,0xbe,0xb5,0x57,0x64,0x98,0x65,0x8,0xd5,0x5a,0x31,0xe8,0x2d,0xe1,
  0x55,0xf1,0x3e,0xe2,0x2d,0x60,0x1b,0x25,0x15,0xcd,0xab,0xa6,0xbc,0xdd,0xee,0xe,
  0x9d,0x63,0xc3,0xe4,0xd5,0x4b,0x52,0x2f,0x3c,0xca,0x44,0xd5,0xb6,0xa9,0x49,0x1d,
  0x35,0xe9,0xe2,0x9d,0xd3,0xdd,0xf,0xd8,0x55,0x82,0x5d,0x2f,0x67,0xc8,0x2f,0x6b,
  0x78,0xae,0x6e,0x97,0x24,0x4,0x47,0xe7,0x2,0x64,0xa8,0x71,0x8a,0x10,0x49,0x20,
  0x35,0xb,0xb,0xc,0xd3,0x1,0x20,0x44,0xe8,0x38,0xdb,0x1c,0x21,0x10,0x8a,0x12,
  0x62,0x90,0x31,0x44,0x13,0x29,0x21,0x49,0xea,0x53,0x1c,0x58,0x42,0xce,0x36,0xa2,
  0x49,0x96,0xc7,0x8b,0xb6,0x7d,0xc3,0xdd,0x86,0x26,0xb8,0xb7,0x34,0x9d,0x2d,0xd8,
  0x95,0x27,0x6b,0x23,0x43,0x63,0x84,0xda,0x80,0xa2,0xd1,0xf,0x54,0x99,0x5f,0xc,
  0xf3,0x2,0x6b,0xd3,0xb0,0x50,0x85,0xb3,0x76,0xf1,0xf8,0x90,0x3e,0x41,0x3b,0x3a,
  0x12,0x5e,0xb2,0xea,0x68,0x4,0x7c,0xae,0x6,0xfe,0xdc,0xd3,0x48,0xa,0xd7,0xf1,
  0xdd,0x81,0x4b,0xbe,0x90,0xa2,0x8c,0xb9,0x5e,0xdf,0x9e,0xf9,0x57,0x19,0x20,0x57,
  0x1e,0x3f,0xe4,0xa5,0xd5,0xd4,0x9a,0xa0,0x8f,0xca,0x7f,0xf2,0xd6,0xc0,0x88,0xa8,
  0xa9,0x5a,0xf4,0xda,0x5a,0x8f,0xed,0x34,0x34,0xf5,0x4e,0x98,0x98,0xc7,0x98,0xbb,
  0xb,0x2a,0xa3,0xa7,0x5a,0x97,0xd1,0x4f,0xad,0x4c,0x62,0xc,0xae,0xf9,0x4c,0xc7,
  0x7,0xba,0x56,0x7d,0x77,0x52,0xdd,0x8c,0x42,0xea,0x51,0x99,0x32,0x96,0x50,0xad,
  0xe3,0x61,0xe5,0x7,0x80,0x2c,0xa8,0x40,0x3a,0x81,0x1,0x2d,0x9b,0xb7,0xd8,0x39,
  0x95,0x4a,0xaa,0x28,0xcb,0x68,0xfc,0xab,0xcc,0xab,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // Treeland
  0x0,0x8,
  0x8,0xbc,0x2f,0x24,
  0x0,0x54,
  0x0,0x72,0x0,0x65,0x0,0x65,0x0,0x6c,0x0,0x61,0x0,0x6e,0x0,0x64,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x95,0x90,0x88,0x3e,0xf8,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x95,0x90,0x88,0x3e,0xf8,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x95,0x90,0x88,0x3e,0xf8,
  // :/qt/qml/Treeland
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x95,0x90,0x88,0x3e,0xf8,
  // :/qt/qml/Treeland/qmldir
  0x0,0x0,0x0,0x2c,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x95,0x90,0x88,0x3e,0xf8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Treeland)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Treeland)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Treeland)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Treeland)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Treeland)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Treeland)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
